package com.sun.org.apache.xerces.internal.jaxp;

import java.util.HashMap;
import com.sun.org.apache.xerces.internal.util.SAXMessageFormatter;
import org.xml.sax.SAXNotRecognizedException;
import org.xml.sax.SAXNotSupportedException;
import org.xml.sax.SAXException;
import javax.xml.parsers.ParserConfigurationException;
import javax.xml.parsers.SAXParser;
import javax.xml.validation.Schema;
import java.util.Map;
import javax.xml.parsers.SAXParserFactory;

public class SAXParserFactoryImpl extends SAXParserFactory
{
    private static final String VALIDATION_FEATURE = "http://xml.org/sax/features/validation";
    private static final String NAMESPACES_FEATURE = "http://xml.org/sax/features/namespaces";
    private static final String XINCLUDE_FEATURE = "http://apache.org/xml/features/xinclude";
    private Map<String, Boolean> features;
    private Schema grammar;
    private boolean isXIncludeAware;
    private boolean fSecureProcess;
    
    public SAXParserFactoryImpl() {
        this.fSecureProcess = true;
    }
    
    @Override
    public SAXParser newSAXParser() throws ParserConfigurationException {
        SAXParser saxParserImpl;
        try {
            saxParserImpl = new SAXParserImpl(this, this.features, this.fSecureProcess);
        }
        catch (SAXException se) {
            throw new ParserConfigurationException(se.getMessage());
        }
        return saxParserImpl;
    }
    
    private SAXParserImpl newSAXParserImpl() throws ParserConfigurationException, SAXNotRecognizedException, SAXNotSupportedException {
        SAXParserImpl saxParserImpl;
        try {
            saxParserImpl = new SAXParserImpl(this, this.features);
        }
        catch (SAXNotSupportedException e) {
            throw e;
        }
        catch (SAXNotRecognizedException e2) {
            throw e2;
        }
        catch (SAXException se) {
            throw new ParserConfigurationException(se.getMessage());
        }
        return saxParserImpl;
    }
    
    @Override
    public void setFeature(String name, boolean value) throws ParserConfigurationException, SAXNotRecognizedException, SAXNotSupportedException {
        if (name == null) {
            throw new NullPointerException();
        }
        if (name.equals("http://javax.xml.XMLConstants/feature/secure-processing")) {
            if (System.getSecurityManager() != null && !value) {
                throw new ParserConfigurationException(SAXMessageFormatter.formatMessage(null, "jaxp-secureprocessing-feature", (Object[])null));
            }
            this.putInFeatures(name, this.fSecureProcess = value);
            return;
        }
        else {
            this.putInFeatures(name, value);
            try {
                this.newSAXParserImpl();
            }
            catch (SAXNotSupportedException e) {
                this.features.remove(name);
                throw e;
            }
            catch (SAXNotRecognizedException e2) {
                this.features.remove(name);
                throw e2;
            }
            return;
        }
    }
    
    @Override
    public boolean getFeature(String name) throws ParserConfigurationException, SAXNotRecognizedException, SAXNotSupportedException {
        if (name == null) {
            throw new NullPointerException();
        }
        if (name.equals("http://javax.xml.XMLConstants/feature/secure-processing")) {
            return this.fSecureProcess;
        }
        return this.newSAXParserImpl().getXMLReader().getFeature(name);
    }
    
    @Override
    public Schema getSchema() {
        return this.grammar;
    }
    
    @Override
    public void setSchema(Schema grammar) {
        this.grammar = grammar;
    }
    
    @Override
    public boolean isXIncludeAware() {
        return this.getFromFeatures("http://apache.org/xml/features/xinclude");
    }
    
    @Override
    public void setXIncludeAware(boolean state) {
        this.putInFeatures("http://apache.org/xml/features/xinclude", state);
    }
    
    @Override
    public void setValidating(boolean validating) {
        this.putInFeatures("http://xml.org/sax/features/validation", validating);
    }
    
    @Override
    public boolean isValidating() {
        return this.getFromFeatures("http://xml.org/sax/features/validation");
    }
    
    private void putInFeatures(String name, boolean value) {
        if (this.features == null) {
            this.features = new HashMap();
        }
        this.features.put(name, value ? Boolean.TRUE : Boolean.FALSE);
    }
    
    private boolean getFromFeatures(String name) {
        if (this.features == null) {
            return false;
        }
        Boolean value = (Boolean)this.features.get(name);
        return value != null && (boolean)value;
    }
    
    @Override
    public boolean isNamespaceAware() {
        return this.getFromFeatures("http://xml.org/sax/features/namespaces");
    }
    
    @Override
    public void setNamespaceAware(boolean awareness) {
        this.putInFeatures("http://xml.org/sax/features/namespaces", awareness);
    }
}
